@@ -10,6 +10,7 @@ from requests import Session
 
 from enum import IntEnum
 
+from .zone import TadoZone
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -173,6 +174,10 @@ class Tado:
         data = self._apiCall(cmd)
         return data
 
+    def getZoneState(self, zone):
+        """Gets current state of Zone as a TadoZone object."""
+        return TadoZone(self.getState(zone), zone)
+
     def getState(self, zone):
         """Gets current state of Zone zone."""
         # pylint: disable=C0103
@@ -346,17 +351,14 @@ class Tado:
 
     def setHome(self):
         """Sets HomeState to HOME """
-        # it seems, this can be set anytime
-        cmd = 'presence'
+        cmd = 'presenceLock'
         payload = { "homePresence": "HOME" }
         data = self._apiCall(cmd, "PUT", payload)
         return data
 
     def setAway(self):
         """Sets HomeState to AWAY """
-        # this can only be set if everybody left the home and 
-        # showHomePresenceSwitchButton = true
-        cmd = 'presence'
+        cmd = 'presenceLock'
         payload = { "homePresence": "AWAY" }
         data = self._apiCall(cmd, "PUT", payload)
         return data
